@@ -27,8 +27,6 @@ Power Spectra Helpers:
 import logging
 
 import numpy as np
-import sparse
-from scipy import ndimage, signal
 
 from . import cycles, imftools
 from ._sift_core import interp_envelope
@@ -82,6 +80,7 @@ def frequency_transform(imf, sample_rate, method, smooth_freq=3,
        1(2), 177–229. https://doi.org/10.1142/s1793536909000096
 
     """
+    from scipy.signal import hilbert
     logger.info('STARTED: compute frequency stats')
 
     imf = ensure_2d([imf], ['imf'], 'frequency_transform')
@@ -94,7 +93,7 @@ def frequency_transform(imf, sample_rate, method, smooth_freq=3,
     if method == 'hilbert':
         logger.info('Using Hilbert transform')
 
-        analytic_signal = signal.hilbert(imf, axis=0)
+        analytic_signal = hilbert(imf, axis=0)
 
         # Estimate instantaneous amplitudes directly from analytic signal
         iamp = np.abs(analytic_signal)
@@ -103,7 +102,7 @@ def frequency_transform(imf, sample_rate, method, smooth_freq=3,
         logger.info('Using Amplitude-Normalised Hilbert transform')
 
         n_imf = imftools.amplitude_normalise(imf)
-        analytic_signal = signal.hilbert(n_imf, axis=0)
+        analytic_signal = hilbert(n_imf, axis=0)
 
         orig_dim = imf.ndim
         if imf.ndim == 2:
@@ -276,7 +275,8 @@ def _fix_quadrature_zero_crossings(quad):
         quad_fix[zc, ii] = np.average(zz[:, np.array((0, 4))], weights=[3/4, 1/4], axis=1)
         quad_fix[zc+2, ii] = np.average(zz[:, np.array((0, 4))], weights=[1/4, 3/4], axis=1)
 
-    quad_fix = ndimage.median_filter(quad_fix, (7, 1))
+    from scipy.ndimage import median_filter
+    quad_fix = median_filter(quad_fix, (7, 1))
 
     return quad_fix
 
@@ -313,10 +313,11 @@ def phase_from_complex_signal(complex_signal, smoothing=None,
         iphase = iphase[:, :, None]
 
     # Apply smoothing if requested
+    from scipy.signal import medfilt
     if smoothing is not None:
         for ii in range(iphase.shape[1]):
             for jj in range(iphase.shape[2]):
-                iphase[:, ii, jj] = signal.medfilt(iphase[:, ii, jj], smoothing)
+                iphase[:, ii, jj] = medfilt(iphase[:, ii, jj], smoothing)
 
     if orig_dim == 2:
         iphase = iphase[:, :, 0]
@@ -358,8 +359,10 @@ def freq_from_phase(iphase, sample_rate, savgol_width=3):
         Array containing the instantaneous frequencies
 
     """
+    from scipy.signal import savgol_filter
+
     # Differential of instantaneous phase
-    iphase = signal.savgol_filter(iphase, savgol_width, 1, deriv=1, axis=0)
+    iphase = savgol_filter(iphase, savgol_width, 1, deriv=1, axis=0)
 
     # Convert to freq
     ifrequency = iphase / (2.0 * np.pi) * sample_rate
@@ -1025,7 +1028,8 @@ def _base_spectra(X, Z,  x_edges):
                    x_inds.shape[1])
 
     # Create sparse spectrum
-    s = sparse.COO(coords, Z, shape=final_shape)
+    from sparse import COO
+    s = COO(coords, Z, shape=final_shape)
 
     return s
 
@@ -1100,7 +1104,8 @@ def _higher_order_spectra(X, Y, Z, x_edges, y_edges):
                    y_inds.shape[2])
 
     # Create sparse spectrum
-    s = sparse.COO(coords, Z, shape=final_shape)
+    from sparse import COO
+    s = COO(coords, Z, shape=final_shape)
 
     return s
 
